# encoding=utf-8
import pickle
import jieba
from gensim import corpora, models, similarities

class Counter:
    def __init__(self):
        self.dict = corpora.Dictionary.load('/Tmp/dd.dict')

    def count(self, sentence):
        seg_line = jieba.cut( sentence, cut_all=False)
        return len(self.dict.doc2bow(seg_line))
    def count_list(self,sentences):
        length = []
        for sentence in sentences:
            seg_line = jieba.cut( sentence, cut_all=False)
            number = len(self.dict.doc2bow(seg_line))
            length.append(number)
        return length




from distutils.core import setup
setup(
  name = 'badWords_zh',
  packages = ['badWords_zh'],
  version = '1.1',
  description = 'Chinese Bad Word Counter',
  author = 'chhsu',
  author_email = 'dev@botimize.io',
  url = 'http://gitlab.botimize.io/chhsu/badWord_counter_zh',
  download_url = 'https://github.com/botimize/badWord_counter_zh/tarball/0.1',
  keywords = ['botimize', 'python', 'badWords', 'chinese', 'data_science'],
  classifiers = [],
)
